@@ -56,12 +56,14 @@ patientProgramRegistration.post(
           registrationStatus: REGISTRATION_STATUSES.RECORDED_IN_ERROR,
         },
         transaction,
+        paranoid: false,
       });
 
       // If the registration was previously recorded in error, update that record to preserve the unique id. Otherwise, create a new one.
       if (existingRecordedInErrorRegistration) {
         registrationRecord = await existingRecordedInErrorRegistration.update(
           {
+            deletedAt: null,
             clinicalStatusId: null,
             deactivatedDate: null,
             deactivatedClinicianId: null,
